script.yaml


flow-stylesclj


make-dumper-optionsclj

(make-dumper-options & {:keys [flow-style]})

creates encoding options

creates encoding options
raw docstring

make-yamlclj

(make-yaml & {:keys [dumper-options unsafe mark]})

Make a yaml encoder/decoder with some given options.

Make a yaml encoder/decoder with some given options.
raw docstring

markclj

(mark start end marked)

Mark some data with start and end positions.

Mark some data with start and end positions.
raw docstring

marked?clj

(marked? m)

Let us know whether this piece of data is marked with source positions.

Let us know whether this piece of data is marked with source positions.
raw docstring

readclj

(read string & {:keys [unsafe mark keywords] :or {keywords true}})

reads map from yaml

reads map from yaml
raw docstring

unmarkclj

(unmark m)

Strip the source information from this piece of data, if it exists.

Strip the source information from this piece of data, if it exists.
raw docstring

writeclj

(write data & opts)

writes map to yaml

writes map to yaml
raw docstring

YAMLCodeccljprotocol

A protocol for things that can be coerced to and from the types that snakeyaml knows how to encode and decode.

A protocol for things that can be coerced to and from the types
that snakeyaml knows how to encode and decode.

decodeclj

(decode data keywords)

encodeclj

(encode data)
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries